class Exceptions():
    """
    Enthält verschiedene Exceptions
    """

    class FetchingError(Exception):
        def __init__(self, message, status_code = None):
            self.message = message
            self.status_code = status_code
            super().__init__(self.message)

    class XMLParsingError(Exception):
        def __init__(self, message):
            self.message = message
            super().__init__(self.message)

    class XMLNotFound(XMLParsingError):
        def __init__(self, message):
            self.message = message
            super().__init__(self.message)


"""
A python module for interacting with a stundenplan24.de substitution plan
"""

from .Vertretungsplan import Vertretungsplan
from .VpDay import VpDay, Klasse, Stunde
from .workflow import Exceptions

__all__ = ['VpMobil', 'Vertretungsplan', 'VpDay', 'Klasse', 'Stunde']
    # Enthält alle Symbole, die bei "from vpmobil import" verfügbar sind
    # Enthält alle Symbole, die bei "from vpmobil import *" importiert werden

class VpMobil:
    """
    Enthält nützliche Funktionen für den Arbeitsablauf

    #### Exceptions
    - .FetchingError
    - .XMLParsingError
        - .XMLNotFound
    """
    FetchingError = Exceptions.FetchingError
    XMLNotFound = Exceptions.XMLNotFound
    XMLParsingError = Exceptions.XMLParsingError

